pub type CredentialHandle = Arc<dyn Credentials>;Expand description
A shared Credentials, because an addon needs it after configuration too.
Aliased Type
pub struct CredentialHandle { /* private fields */ }pub type CredentialHandle = Arc<dyn Credentials>;A shared Credentials, because an addon needs it after configuration too.
pub struct CredentialHandle { /* private fields */ }